@@ -873,7 +873,7 @@ DTSg <- R6Class(
 
       plot <- dygraphs::dygraph(
         as.xts.data.table(private$.values[
-          .dateTime >= from & .dateTime <= to,
+          between(.dateTime, from, to),
           c(".dateTime", cols),
           with = FALSE
         ]),
@@ -1044,7 +1044,7 @@ DTSg <- R6Class(
       cols = self$cols(class = "numeric")[1L],
       before = 1L,
       after = before,
-      weights = c("inverseDistance"),
+      weights = "inverseDistance",
       parameters = list(power = 1),
       resultCols = NULL,
       suffix = NULL,
